function RemoteServer (id, controller) 
{
	// Call superconstructor first (AutomationModule)
	RemoteServer.super_.call(this, id, controller);

}

inherits(RemoteServer, AutomationModule);
_module = RemoteServer;

// ----------------------------------------------------------------------------
// --- Module instance initialized
// ----------------------------------------------------------------------------

RemoteServer.prototype.init = function (config) 
{
	var self = this;

	// Call superclass' init (this will process config argument and so on)
	RemoteServer.super_.prototype.init.call(this, config);

	self.debug = true;
	self.ourinstance = self.controller.instances.filter(function(instance) {return instance.id == self.id});
	if (self.ourinstance.length)
		self.ourinstance = self.ourinstance[0];

	try
	{
		self.sockServer = new sockets.websocket(9001);
		self.log("Starting server on port 9001 (" + self.sockServer + ")");

		self.sockServer.onconnect = function()
		{
			self.log("    client connected");
		}
		self.sockServer.onmessage = function(ev)
		{
			self.log("    socket recv: " + JSON.stringify(ev));
		}
		self.sockServer.onclose = function()
		{
			if (this === self.sockServer)
				self.log("    server closed");
			else
				self.log("    client disconnected");
		}
		self.sockServer.onerror = function(ev)
		{
			self.log("    socket error: " + JSON.stringify(ev));
		}
	} catch(e) {self.log("Error setting up server (" + e.message + ")");}

	console.log("")
};

RemoteServer.prototype.stop = function () 
{
	var self = this;
	if (self.sockServer)
	{
		console.log("Closing server");
		self.sockServer.close();
	}

	RemoteServer.super_.prototype.stop.call(this);
};

RemoteServer.prototype.log = function(string)
{
	try
	{
		var self = this;
		if (self.debug)
		{
			console.log((self.ourinstance ? self.ourinstance.title + ": " : "") + string);
		}
	} catch (e)
	{
		console.log("An error occured trying to log the entry (" + e.message + ")");
	}
}